import React, { useEffect, useRef, useState } from 'react'

import { Row, Col, Upload, message, UploadProps} from 'antd'

import { LoadingOutlined, PlusOutlined } from '@ant-design/icons';

import { uploadImage } from '@/services/api/upload'

import Global from '@/common/global'
import './index.less'

interface IProps {
  imageUrl: string,
  saveImageUrl: (imgUrl: string) => void,
  uploadCount?: number, // -1 代表可反复上传 0 代表不能上传 > 1 代表上传次数
  title: string,
  onClick?: (imageUrl: string) => void
}

const UploadImage: React.FC<IProps> = ({
  saveImageUrl,
  imageUrl,
  uploadCount = -1,
  title,
  onClick
}) => {
  
  const [ loading, setLoading ]  = useState<boolean>(false)
  const uploadCountRef = useRef<number>(uploadCount)
  
  useEffect( () => {
    imageUrl && setLoading(false)
  }, [imageUrl])

  const action = Global.getIsDev ? '/api' : Global.getBaseUrl

  const allowClick = uploadCountRef.current !== 0

  const beforeUpload = (e: any) => {
  }

  const handleChange = (info: { file: { status: string; originFileObj: any; response: any }; }) => {
    if (info.file.status === 'uploading') {
      setLoading(true)
      return;
    }
    if (info.file.status === 'done') {
      if (info.file.response.status === 200) {
        saveImageUrl(info.file.response.result)
        changeUploadCount()
      }
    }
  }

  /** 上传次数修改 */
  const changeUploadCount = () => {
    if (uploadCountRef.current >= 1) {
      uploadCountRef.current--
    }
  }

  const uploadLoadingButton = (
    <div style={{display: "flex", flexDirection: 'column', justifyContent: 'center', alignItems: 'center'}} >
      {loading ? <LoadingOutlined /> : <PlusOutlined />}
      <div style={{ marginTop: 8 }}>{ title  }</div>
    </div>
  );

  return (
    <Row style={{width: '100%'}} > 
    {/* style={{ width: '80px', height: '80px',border: '1px solid #000', display: "flex", justifyContent: 'center', alignItems: 'center' }} */}
      <Col span={24} >
          <Upload
              openFileDialogOnClick={allowClick}
              style={{width: '80px', height: '80px'}}
              name="file"
              listType="picture-card"
              className="avatar-uploader"
              showUploadList={false}
              action={ action  + 'gamecontest/admin/file/uploadImage' }
              data={{
                token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJhdWQiOiIxMzY2NzAwNTY3OTUzMzYyOTQ2IiwiZXhwIjoxNjIxODI1MDEzfQ.8LLmL6Mfb_pQxLjDmM13ekzq7nnWGWwWuANLQHvF3CM',
              }}
              beforeUpload={beforeUpload}
              onChange={handleChange}
            >
            {imageUrl 
              ? 
              <img  src={imageUrl} alt="avatar" style={{ width: '80px' }} /> 
              : 
              uploadLoadingButton
            } 
          </Upload>
      </Col>
    </Row>
  )
}

export default UploadImage


