import React, { useEffect, useState } from 'react'

import BaseTmp from '@/components/BaseTmp'

import { Row, Col, Button, Table, Space, Divider, Modal, Input, message, Popconfirm } from 'antd'

import { getSectionExcludState, addSection, updateSection, opSection } from '@/services/api/section'


type TSection = Partial<Pick<API.Section, 'semesterName' | 'semesterDescription' | 'id' >>

interface ISectionModal {
  visable: boolean,
  type: 'add' | 'update',
  onCancel: () => void,
  onChange: (e: React.FormEvent<HTMLInputElement>, keyname: 'semesterName' | 'semesterDescription' ) => void
  section: TSection,
  submit: () => void
}

/**新增弹窗 */
const SectionModal: React.FC<ISectionModal> = ({
  type,
  visable,
  section,
  onChange,
  onCancel,
  submit
}) => {
  const title = type === "add" ? '新增学段' : "编辑学段"
  return (
    <Modal 
      title={title}
      visible={visable}
      closable={false}
      onOk={submit}
      onCancel={onCancel}
    >
      <Row>
        <Col>
          <span>学段名称：</span> 
          <Input 
            style={{width: '300px'}} 
            value={section.semesterName}
            onInput={(e) => onChange(e, "semesterName") }
            maxLength={10} 
            showCount
          />
        </Col>
        <Col 
          style={{marginTop: '20px'}}  
        >
          <span>学段描述：</span> 
          <Input 
            style={{width: '300px'}}
            onInput={(e) => onChange(e, "semesterDescription") }
            value={section.semesterDescription} 
          />
        </Col>
      </Row>
    </Modal>
  )
}


const initSection = {
  semesterName: '',
  semesterDescription: '',
  id: ''
}

const SchoolSection = () => {

  const [ sectionList, setSectionList ] = useState<API.Section[]>([])

  const [ visable, setVisable ] = useState<boolean>(false)

  const [ type, setType ] = useState<'add' | 'update'> ('add')

  const [ section, setSection ] = useState<TSection>(initSection)

  const [ loading, setLoading ] = useState<boolean>(false)

  useEffect( () => {
    GetSectionExcludState()
  }, [])
  
  /***关闭弹窗 */
  const closeModal = () => setVisable(false)

  /**打开弹窗 */
  const openModal = () => setVisable(true)

  const onAddSection = () => {
    openModal()
    setType("add")
  }

  /**更改section字段 */
  const onChange = (
    e: React.FormEvent<HTMLInputElement>, 
    type: 'semesterName' | 'semesterDescription'
  ) => {
    console.log("e:", e);
    
    setSection({
      ...section,
      [type]: e.target.value
    })
  }

  const onUpdateSection = (records: API.Section) => {
    openModal()
    setType("update")
    setSection(records)
  }

  const submit = () => {
    if (type === 'add') {
      AddSection() 
    } else {
      UpdateSectionp()
    }
  }

  /**操作学段 */
  const OpSection = async (records: API.Section) => {
    const {status, result  } = await opSection({
      id: records.id, status: "-1"
    })
    if ( status === 200 ) {
      console.log(result);
      message.success('删除成功')
      GetSectionExcludState()
    }
  }

  /** 新增学段 */
  const AddSection = async () => {
    const $par = section
    const { status, result } = await addSection({
      semesterName: $par.semesterName as string, 
      semesterDescription: $par.semesterDescription as string
    })
    if ( status === 200) {
      console.log(result);
      message.success('新增成功')
      setSection(initSection)
      closeModal()
      GetSectionExcludState()
    }  
  }

  /**编辑学段 */
  const UpdateSectionp = async () => {
    const $par = section
    const { status, result } = await updateSection($par)
    if ( status === 200) {
      console.log(result);
      message.success('新增成功')
      setSection(initSection)
      closeModal()
      GetSectionExcludState()
    }
  }
  
  /** 列表查询学段-不包含禁用状态 */
  const GetSectionExcludState = async () => {
    setLoading(true)
    const { result, status } = await getSectionExcludState()
    setLoading(false)
    if ( status === 200 ) {
      setSectionList(result)
    }
  }

  const columns = [
    {
      title: '学段名',
      dataIndex: 'semesterName',
      key: 'semesterName'
    },
    {
      title: '学段描述',
      dataIndex: 'semesterDescription',
      key: 'semesterDescription'
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      key: 'createTime'
    },
    {
      title: '操作',
      dataIndex: 'action',
      key: 'action',
      render: (action, records: API.Section) => 
        <Space>   
          <a  onClick={() => onUpdateSection(records)} >编辑</a>
          <Divider type="horizontal" />
          <Popconfirm
            title="确定要删除这个学段吗？"
            onConfirm={() => OpSection(records)}
          >
            <a>删除</a>
          </Popconfirm>
        </Space>
    }
  ]

  return (
    <BaseTmp>
      
      <Row justify="end" >
        <Col>
          <Button type="primary"  onClick={onAddSection} > 新增 </Button>
        </Col>
      </Row>

      <Table
        loading={loading}
        style={{marginTop: '20px'}} 
        dataSource={sectionList}  
        columns={columns} 
      />

      <SectionModal 
        type={type}
        visable={visable}
        section={section}
        onCancel={closeModal}
        onChange={onChange}
        submit={submit}
      />

    </BaseTmp>
  )

}


export default SchoolSection


