import React, { forwardRef, useEffect, useLayoutEffect, useRef, useState } from 'react'
import BaseTmp from '@/components/BaseTmp';
import { Row, Col, Radio, RadioChangeEvent, Select, Input, Button, message, Tooltip, Modal, Image } from 'antd'
import classNames from 'classnames';
import type { Position } from 'react-rnd';
import { Rnd } from 'react-rnd'
import styles from './style/index.less'
import { useStatePrevious } from '@/hooks'
import RightClick from '@/components/RightClick'
import UploadImg from '@/components/UploadImage/index'
import api from '@/services/api'
import { history, useLocation, useParams, useRouteMatch } from 'umi';

import iPhonexBangs from '@/static/common/iPhoneX-top.png'

import { getSectionExcludState } from '@/services/api/section'

import { CloseCircleOutline, QuestionCircleOutlined } from '@ant-design/icons'

import './style/preview.less'

const bg = "https://app-resources-luojigou.luojigou.vip/FhaDyMVgzWGpaTqZTHlGBWN1oKzp";

const TipText = `鼠标双击删除图片`

const {
  getQuestionBank,
  addQuestionCard,
  getQuestionCardByid,
  putQuestionCard
} = api.question

type TMerge = IQPData & IQData & IIData & {
  color: string,
  imgUrl: string,
  bg: string,
  id: number
}

interface IQPData {
  pw: number,
  ph: number,
  px: number,
  py: number
}

interface IQData {
  w: number,
  h: number,
  x: number,
  y: number
}

/** 命名和小程序对应 */
interface IIData {
  iw: number,
  ih: number,
  ix: number,
  iy: number
}

type TType = 'parent' | 'children' | 'button' | 'bg'

/** 红 绿 黄 蓝 */
const colorList = [
  {color: '#FA0F0C', label: '红色'},
  {color: '#396C28', label: '绿色'},
  {color: '#F7DF1E', label: '黄色'},
  {color: '#23398C', label: '蓝色'},
  {color: '', label: ''}
]

const QPData = { pw: 90, ph: 90, px: 20, py: 80}
const QData = { w: 60, h: 60, x: 0, y: 0}
const QIData = { iw: 40, ih: 40,  ix: 0, iy: 0 }

const permutationKey = ( type: TType ) => {
  
  if ( type === 'parent' || type === 'bg' ) return ['pw', 'ph', 'px', 'py']
  else if ( type === "children" ) return ['w', 'h', 'x', 'y']
  else return ['iw', 'ih', 'ix', 'iy']

}

interface IQuestionCard {
  content: TMerge[],
  onResizeStop: (
    type: TType,
    {w, h, pos}: {w: string, h: string, pos: Position},
    index?: number,
  ) => void,
  resizeChildrenRnd: (index: number) => void
  label: string,
  onInput: (e: InputEvent) => void,
  deleteImg: ( _imgUrl: string ) => void,
  onDragStop: (type: TType,  index: number, {x, y}: {x: number, y: number}) => void
  saveImageUrl: (imgUrl: string, index: number) => void,
  addBackgoundPicture: () => void,
  onClick: (id: string | number, e: any) => void,
}

const QuestionCard: React.FC<IQuestionCard> = ({
  content,
  onResizeStop,
  label,
  deleteImg,
  onInput,
  saveImageUrl,
  onDragStop,
  addBackgoundPicture,
  onClick
}) => {

  const [ menuState, setMenuState ] = useState<boolean>(false)

  const bordeLiene = classNames(styles['border-line'], styles['question-card-timing'])

  const questionId = 'questionId'

  const backgroundList = content.length >= 1 && content?.filter( item => item.bg === 'true' )

  const _content = content.length >= 1 && content?.filter( item => item.bg === 'false')
  
  /**
   * 
   * @description 鼠标右键事件
   * 
   */

  const pictureRightClick = ( e: React.MouseEvent ) => {

    e.preventDefault()

    console.log("鼠标右键事件:", e);
    if (e.target.id === 'questionId') {
      if (e.button === 2) {
        console.log("鼠标右键事件:", true);
        setMenuState(true)
      }
    } else {
      setMenuState(false)
    }
    
  }

  const changeRnder = () => {
    setMenuState(false)
  }

  const RenderButton = ({color}: {color: string}) => {
    return <div className={styles['render-button']} style={{backgroundColor: color}} />
  }

  return (
    <div className={styles.question} >
      <RightClick  
        render={menuState} 
        deleteImg={(_imgUrl) => deleteImg(_imgUrl)}
        changeRnder={changeRnder}
      />
      <div className={styles['question-card-iphonex']} >
        <img src={iPhonexBangs} alt="" />
      </div>
      <Row  className={bordeLiene} justify='center' align='middle' >
        <Col span={24} >计时区</Col>
      </Row>
      <Row className={styles.stem} justify='center' align='middle' >
        <Col span={24} >
          <Input.TextArea 
            style={{height: '90px'}} 
            placeholder="请输入题卡描述" 
            maxLength={6}
            value={label}
            onInput={onInput}
          />
        </Col>
      </Row>
      <Row className={styles['opration-area']}  justify="center" >
        <Col 
          className={styles['opration-left']}
        >
          {
            _content && _content?.map( (item, index) => (
                <Rnd
                  key={index}
                  minHeight={20}
                  minWidth={20}
                  bounds='parent'
                  className='parent-rnd'
                  style={{ border: `1px solid ${item.color}`, zIndex: 2}}
                  size={{ width: item.pw,  height: item.ph }}
                  position={{ x: item.px, y: item.py }}
                  onDragStop={(e, d) => { onDragStop('parent', item.id, { x: d.x, y: d.y }) }}
                  onResizeStop={(e, direction, ref, delta, position) => {
                    onResizeStop('parent',  {
                      w: ref.style.width,
                      h: ref.style.height,
                      pos: position,
                    }, item.id);
                  }}
                >
                  {/* 问题 */}
                  <Rnd
                    key={`child-${index}`}
                    bounds='parent'
                    onMouseDown={e => e.stopPropagation()}
                    style={{ border: `1px dashed ${item.color}`}}
                    size={{ width: item.w,  height: item.h }}
                    position={{ x: item.x, y: item.y }}
                    onDragStop={(e, d) => { onDragStop( 'children', item.id, { x: d.x, y: d.y }) }}
                    onResizeStop={(e, direction, ref, delta, position) => {
                      onResizeStop( 'children',{
                        w: ref.style.width,
                        h: ref.style.height,
                        pos: position,
                      }, item.id);
                    }}
                  > 
                  {
                    item?.imgUrl ? 
                      <img
                        src={item?.imgUrl}
                        id={questionId}
                        style={{width: item.w + 'px',  height: item.h  + 'px', boxSizing: 'border-box', display: 'block'}}
                        onDoubleClick={(e) => onClick(item.id, e)}
                    />
                    :
                    <UploadImg 
                      title='上传试题'
                      imageUrl={item?.imgUrl}
                      saveImageUrl={ (imgUrl) => saveImageUrl(imgUrl, item.id)}
                      uploadCount={1}
                    />
                  }
                  </Rnd>
                  {/* 圆钮 */}
                  <Rnd
                    key={`button-${index}`}
                    bounds='parent'
                    onMouseDown={e => e.stopPropagation()}
                    size={{ width: item.iw,  height: item.ih }}
                    position={{ x: item.ix, y: item.iy }}
                    onDragStop={(e, d) => { onDragStop( 'button', item.id, { x: d.x, y: d.y }) }}
                  >
                    { item.color ? <RenderButton color={item.color}  /> : null}
                  </Rnd>
                </Rnd>
            ))
          }
          {/* 背景图 */}
          {
            backgroundList && backgroundList.length >= 1 &&

            backgroundList.map( (bg, index) =>
              <Rnd
                key={index}
                minHeight={20}
                minWidth={20}
                bounds='parent'
                style={{ 
                  border: `1px solid blue`,
                  zIndex: 1,
                  background: `url(${bg?.imgUrl}) no-repeat  center/100% 100% `,
                  display: 'block'
                }}
                position={{ x: bg.px, y: bg.py }}
                size={{width: bg.pw, height: bg.ph}}
                onDragStop={(e, d) => { onDragStop( "bg", bg.id, { x: d.x, y: d.y }) }}
                onResizeStop={(e, direction, ref, delta, position) => {
                  onResizeStop( 'bg', {
                    w: ref.style.width,
                    h: ref.style.height,
                    pos: position,
                  }, bg.id);
                }}
              >
                {
                  bg?.imgUrl 
                  ? 
                  <div
                    style={{
                      width: bg.pw + 'px',
                      height: bg.ph + 'px',
                      position: 'absolute',
                      top: 0,
                      left: 0
                    }}
                    onDoubleClick={(e) => onClick(bg.id, e)}
                  /> :
                  <UploadImg 
                    imageUrl={bg?.imgUrl as string}
                    saveImageUrl={(imgUrl) => saveImageUrl(imgUrl, bg.id)}
                    title='上传背景'
                    uploadCount={1}
                  /> 
                }
              </Rnd>
            )
          }
        </Col>
        <Col className={styles['answer-area']} > 答案区域 </Col>
      </Row>
      {/* 底部操作按钮 */}

      <Row 
        style={{
          width: "378px", 
          height: '50px', 
          borderTop: 'none',
          marginTop: "-2px", 
          marginLeft: '-1px',
          paddingLeft: '20px'
        }}
        align="middle"
      >
        <Col>
          <Button  type="primary" onClick={addBackgoundPicture} > +背景 </Button>
        </Col>
      </Row>
    </div>
  )
}

interface IAnswer {
  color: string,
  imgUrl: string
}

interface IAnswerCard {
  onChangeAnswer: (e: RadioChangeEvent, index: number) => void,
  saveImageAnswerUrl: (imgUrl: string, index: number) => void,
  answerList: IAnswer[]
}

const AnswerCard: React.FC<IAnswerCard> = ({
  onChangeAnswer,
  saveImageAnswerUrl,
  answerList
}) => {

  /**渲染颜色选择radio */
  const RenderColorRadio = ({_color, index}: {_color: string, index: number}) => {
    return (
      <Radio.Group  value={_color} >
        {
          colorList.map( (_color, i) => (
            _color.color ? 
              <Radio 
                value={_color.color} 
                key={_color.color} 
                onChange={(e) => onChangeAnswer(e, index)}
              >
                {_color.label}
              </Radio>
              :
              <></>
            )
          )
        }
      </Radio.Group>
    )
  }

  /** @description 答案选择render */
  const RenderAnswer = () => {

    return (
      <Row style={{width: '100%'}}>
        {
          answerList.map( (answer, index) => (
            <Col span={24} key={index} > 
              <Row gutter={3} style={{width: '100%'}} align="middle" justify="space-around" >
                <Col>选项1:</Col>
                <Col>
                  <UploadImg 
                    title=''
                    saveImageUrl={(imageUrl) => saveImageAnswerUrl(imageUrl, index) } 
                    imageUrl={answer?.imgUrl}
                  />
                </Col>
                <Col>对应答案</Col>
                <Col> 
                  <RenderColorRadio  _color={answer.color} index={index} />
                </Col>
              </Row>
            </Col>
          ))
        }
      </Row>
    )
  }

  return (
    <Row className={styles['answer-card'] }  >
      <Col
        span={24}
        className={styles['ability-point']}
      >
        &nbsp;
        {/* 能力选择: */}
      </Col>
      <Col
        span={24}
        className={styles['answer-setting']} 
        style={{height: '232px', borderTop: '1px solid #000', paddingTop: '40px'}} 
      >
        <RenderAnswer />
      </Col>
    </Row>
  )
}

interface ISelectTmp {
  defaultValue: string
  dataList: Record<string, any>[],
  onChange: (value: string) => void
}

const SelectTmp: React.FC<ISelectTmp> = ({
  dataList,
  onChange,
  defaultValue
}) => {
  
  return <Select defaultValue={defaultValue}  style={{ width: 300 }} onChange={onChange} >
            {
              dataList.map( data => 
                <Select.Option value={data.id} key={data.id} >{data.label}</Select.Option>)
            }
          </Select>
}

const QuestionBankManage: React.FC = () => {

  const [ bankList, setBankList  ] = useState<{id: string, label: string}[]>([])

  const [ currentBank, setCurrentBank ] = useState<{id: string, label: string}>({
    id: '',
    label: ''
  })

  const [ title, setTitle ] = useState<string>()

  const [ content, setContent ] = useState<TMerge[]>([])

  const [ previous, setPrevious ] = useStatePrevious<TMerge[]>()

  const [ label, setLabel ] = useState<string>('')

  /**当前操作的父盒子下标 */
  const [ OIndex, setOIndex ] = useState<number>()

  const [ answerList, setAnswerList ] = useState<IAnswer[]>([
    {color: '', imgUrl: ''},
    {color: '', imgUrl: ''},
    {color: '', imgUrl: ''},
    {color: '', imgUrl: ''},
  ])

  /**能力点 */
  const [ ability, setAbility ] = useState<string>('')

  const [ sectionList, setSectionList  ] = useState<API.Section[]>([])

  const [ section, setSection ] = useState<Pick<API.Section, 'id' | 'semesterName'>>({
    id: '',
    semesterName: ""
  })

  /**预览弹窗 */
  const [ previewVisible, setPreviewVisible ] = useState<boolean>(false)


  console.log(answerList);
  

  const location = useLocation()

  const cardId = location.query.cardId

  const submitButtonLabel = cardId ? '保存并发布' : '保存并发布'

  const bgData = {
    bg: "true",
    px: 0, 
    py: 0,
    pw: 100,
    ph: 100,
    imgUrl: '',
    w: 0,
    h: 0,
    x: 0,
    y: 0,
    iw: 0,
    ih: 0,
    ix: 0,
    iy: 0,
    color: ''
  }

  useEffect( () => {
    _getQuestionBank()
    GetSectionExcludState()
  }, [])

  useEffect( () => {
   
    if (cardId) {
      _getQuestionCardByid(cardId)
    } else {
      initContent()
    }
  }, [])

  useEffect( () => {
    
    (typeof OIndex === 'number' || typeof OIndex === "string" ) && resizeChildrenRnd(OIndex!)
    
  }, [previous])

  /**删除试题获取背景图 */
  const onClear = ( id: string | number , e: any) => {
    console.log("删除试题获取背景图:", id, e);
    
    const r = content.map(  item =>  {
      if ( item.id === id && item.bg === 'false') {
        return {
          ...item,
          imgUrl: ''
        }
      } else if (item.id === id && item.bg === 'true') {
        return false
      } else {
        return item
      }
    }).filter( _ => !!_ )
    console.log(r);
    
    setContent(r)
  }

  /**保存结果答案 */
  const saveImageAnswerUrl = (imgUrl: string, index: number) => {
    const r = answerList.map( (answer, i) => {
      return {
        ...answer,
        imgUrl: index === i ? imgUrl: answer?.imgUrl
      }
    })
    setAnswerList(r)
  }

  /** */
  const onChangeAnswer =  (e: RadioChangeEvent, index: number) => {
    const r = answerList.map( (answer, i) => {
      return {
        ...answer,
        color: index === i ? e.target.value: answer.color
      }
    })
    setAnswerList(r)
  }

  /**修改title */
  const onInputTitle = (e: InputEvent) => setTitle(e.target.value)
  
  /**修改title */
  const onInputAbility = (e: InputEvent) => setAbility(e.target.value)

  const onInput = (e: InputEvent) => setLabel(e.target.value)

  /** 保存图片 */
  const saveImageUrl = (imgUrl: string, id: number) => {

    const r = content?.map( (item, i) => { 
      return {
        ...item,
        imgUrl: id === item.id ? imgUrl : item.imgUrl
      }
    })

    setContent(r)
 
  }

  const onDragStop = (
    type: TType,
    index: number,
    {x, y}: {x: number, y: number},

  ) => {

    const [ _w, _h , _x, _y ] = permutationKey(type)

    const r = content?.map( (item, i) => {
      console.log(item.id, index);
      
      const target = item.id === index
      return {
        ...item,
        [_x]: target? x.toFixed(2) : item[_x],
        [_y]: target? y.toFixed(2) : item[_y]
      }
    })

    setContent(r)

  }

  const deleteImg = (_imgUrl: string) => {
    const r = content?.map( (item, index) => {
      return {
        ...item,
      imgUrl: _imgUrl === item.imgUrl ? '' : item.imgUrl
      }
    })
    setContent(r)
  }

  /**
   * @description 初始化init数据
   */

  const initContent = () => {
      let mergeList: TMerge[] = []
      Array.from(new Array(4)).forEach( (count, index) => {
        
        const even = index % 2 === 0
        
        const lt = index < 2

        const _QPData = {
          ...QPData, 
          px: even ? 100 : 10, 
          py:  lt ? 80 : 200,
        }

        mergeList.push({
            ..._QPData,
            ...QData,
            ...QIData, 
            color: colorList[index].color,
            imgUrl: '',
            bg: "false",
            id: index
          }
        )
      })

      setContent(mergeList)
  }

  const onChangeBank = (id: string) => {
    const bank = bankList.find( bank => bank.id === id )

    console.log("bank:", bank);
    
    setCurrentBank({
      ...bank,
      id
    })
  }

  const onChangeSection = (id: string) => {
    const _section = sectionList.find( section => section.id === id ) as API.Section
    setSection({
      ..._section,
      id
    })
  }

  /**
   * 
   * @description 当父盒子缩小 宽高小于子盒子时 按照缩放比例 缩小子盒子
   * 
  */

  const resizeChildrenRnd = ( index: number) => {

      const _previous: TMerge = previous!.filter( previou => previou.id === index )[0]
  
      const _contentItem = content!.filter( item => item.id === index )[0]
  
      let rate = 1
  
      let _ix = 0
      let _iy = 0
  
      if ( _contentItem.pw < _contentItem.w  ) {
  
        rate = _contentItem.pw / _previous.pw
  
      } else if ( _contentItem.ph < _contentItem.h ) {
  
        rate = _contentItem.ph / _previous.ph
  
      }
  
      if ( _contentItem.pw < (_contentItem.ix + _contentItem.iw)) {
  
        _ix = _contentItem.pw - _contentItem.iw
      } else if (_contentItem.ph < (_contentItem.iy + _contentItem.ih)) {
  
        _iy = _contentItem.ph - _contentItem.ih
      }
  
      const r = content?.map( (item, i) => {
        const target = item.id === index
        return {
          ...item,
          w: target? item.w * rate: item.w,
          h: target? item.h * rate: item.h,
          x: target? item.x * rate: item.x,
          y: target? item.y * rate: item.y,
          ix:  target && _ix !== 0 ? _ix : item.ix,
          iy:  target && _iy !== 0 ? _iy : item.iy,
        }
      })
  
      setContent(r)
  }
  
  /**修改题卡大小 */
  const onResizeStop = (
    type: TType,
    {w, h, pos}: {w: string, h: string, pos: Position},
    index?: number,
  ) => {

    const rw = Number(w.replace('px', '')).toFixed(2)

    const rh = Number(h.replace('px', '')).toFixed(2)

    const [ _w, _h , _x, _y ] = permutationKey(type)

    console.log('修改题卡大小:',  rw,  rh, index);
    
    const r = content?.map( (item, i) => {
      const target = item.id === index
      return {
        ...item,
        [_w]: target? rw : item[_w],
        [_h]: target? rh : item[_h],
        [_x]: target? pos.x.toFixed(2) : item[_x],
        [_y]: target? pos.y.toFixed(2) : item[_y]
      }
    })
    if (type === 'parent' || type === "bg") {
      setPrevious(content!)
    }
    setContent(r)
    console.log("修改题卡大小:", index);
    setOIndex(index)
  }

  /***根据id获取卡片数据, 用于编辑 */
  const _getQuestionCardByid = async (cardId: string) => {

    const { status, result } = await getQuestionCardByid(cardId)

    if ( status === 200 ) {
      
      setContent(result.content)
      setAnswerList(result.options)
      setLabel(result.label)
      setTitle(result.title)
      setAbility(result.ableVar)
      
      setCurrentBank({
        label: result.bankName,
        id: result.bankId
      })

      setSection({
        semesterName: result.semesterName,
        id: result.semesterId
      })
    }

  }

  /**返回上一次 */
  const goback = () => {
    history.goBack()
  }

  /** submit question card */
  const submit = (state: 0 | 1 ) => {

    const _colorlist = answerList.map( answer => answer.color )

    if (!title?.length) {
      message.error("请填写卡片标题")
      return 
    }

    if (!ability?.length) {
      message.error("请填写能力点")
      return 
    }


    if ( !section.id ) {
      message.error("请选择学段")
      return 
    }


    if (!label.length) {
      message.error("请填写卡片描述")
      return 
    }

    if (_colorlist.includes('')) {
      message.error("存在未选择的答案")
      return
    }

    let hasSameColor = false
    _colorlist.forEach( (_color, index) => {
      const r = _colorlist.lastIndexOf(_color)
      if ( r !== -1 && r !== index ) {
        hasSameColor = true
      }
    })

    if (hasSameColor) {
      message.error("存在一样的答案")
      return
    }
    
    const r2 = content.filter( item => !item?.imgUrl && item.bg === "false" ).length

    const r3 = answerList.filter( item => !item?.imgUrl ).length

    if( r2 ) {
      message.error("存在未上传的问题")
      return
    }

    if( r3 ) {
      message.error("存在未上传答案封面")
      return
    }

    /**为了和小程序 保持同步 小程序背景图取的w h */
    const _content = content.map( item => {
      if (item.bg === 'true') {
        return {
          ...item,
          w: item.pw,
          h: item.ph
        }
      } else {
        return item
      }

    })

    const $par = {
      content: _content,
      options: answerList,
      label,
      title,
      semesterId: section.id,
      ableVar: ability,
      id: cardId ? cardId : '',
      bankId: currentBank?.id,
      bankLabel: currentBank?.label,
      semesterName: section?.semesterName
    }

    _addQuestionCard(state, $par)
  }

  /**增加背景图 */
  const addBackgoundPicture = () => {

    const len = content.filter( item => item.bg === 'true' ).length

    if (len === 3) {
      message.error('背景图最多三张')
      return
    }

    const copyContent = JSON.parse( JSON.stringify(content))
    
    copyContent.push({
      ...bgData,
      id: content.length
    })
    
    setContent(copyContent)

  }

  /**增加题卡 state -->  0保存 1发布  */
  const _addQuestionCard = async (state: 1 | 0, $par: any) => {
    let $r = null
    if (cardId) {
      $r = await putQuestionCard(state, $par)
    } else {
      $r = await addQuestionCard(state, $par)
    }
    if ( $r.status === 200 ) {
      message.success( cardId ? "编辑成功" : "增加成功" )
      history.goBack()
    }

  }

  /**获取题库 */
  const _getQuestionBank = async () => {
    const { status, result } = await getQuestionBank()
    if ( status === 200 ) {
      setBankList(result)
    }
  }

  /**获取学段 */
  const GetSectionExcludState = async  () => {
    const { status, result } = await getSectionExcludState()
    if ( status === 200 ) {
      setSectionList(result)
    }
  }

  /** 预览游戏 */

  const previewView = () => {
      setPreviewVisible(true)
  }

  return (
    <BaseTmp>
      <Row  style={{marginTop: '20px', width: '100%'}} >
        <Col span={2} > 题库名称：  </Col>
        <Col>  
          <SelectTmp 
            key={currentBank.id}  
            defaultValue={currentBank.id} 
            dataList={bankList} 
            onChange={onChangeBank} 
          />
        </Col>
      </Row>
      <Row style={{marginTop: '20px'}} >
        <Col span={2}  > 学段：  </Col>
        <Col> 
        
          <Select key={section.id} defaultValue={section.id}  style={{ width: 300 }} onChange={onChangeSection} >
     
            {
              sectionList.map( data =>
                <Select.Option
                  value={data.id}
                  key={data.id}
                >
                  {data.semesterName}
                </Select.Option>
              )
            }
          </Select>
         </Col>
      </Row>
      <Row  style={{marginTop: '20px'}} >
        <Col span={2}  > 卡片名称：  </Col>
        <Col> <Input style={{ width: "300px" }} onInput={onInputTitle} value={title}  /> </Col>
      </Row>
      <Row style={{marginTop: '20px'}} >
        <Col span={2}  > 能力点：  </Col>
        <Col> <Input onInput={onInputAbility} value={ability}  /> </Col>
      </Row>
      <Row 
        className={styles['question-bank-manage']}
        style={{marginTop: '20px'}} 
      >
        <Col>
          题卡：<br />
          <Tooltip placement="top"  title={TipText} >
            <QuestionCircleOutlined />
          </Tooltip>
        </Col>
        <Col span={7.5} >
          <QuestionCard
            label={label}
            content={content}
            onDragStop={onDragStop}
            resizeChildrenRnd={resizeChildrenRnd}
            onResizeStop={onResizeStop}
            onInput={onInput}
            deleteImg={deleteImg}
            saveImageUrl={saveImageUrl}
            addBackgoundPicture={addBackgoundPicture}
            onClick={(id, e) => onClear(id, e)}
          />
        </Col>
        <Col span={13.5}>
          <AnswerCard
            answerList={answerList}
            saveImageAnswerUrl={saveImageAnswerUrl}
            onChangeAnswer={onChangeAnswer}
          />
        </Col>
      </Row>
      <Row justify="center" style={{marginTop: "100px"}} >
      <Col span={2} >
          <Button   onClick={goback} > 
            取消
          </Button>
        </Col>
        <Col span={2} >
          <Button  type="primary" onClick={() =>  submit(0)} > 
            保存
          </Button>
        </Col>
        <Col span={2} >
          <Button  type="primary" onClick={previewView} > 预览 </Button>
        </Col>
        
        <Col span={2} >
          <Button type="primary" onClick={() =>  submit(1)} >
            {submitButtonLabel}
          </Button>
        </Col>
      </Row>

      <Modal
        title="预览"
        visible={ previewVisible }
        closable={false}
        onCancel={() =>  setPreviewVisible(false)}
        onOk={ () => setPreviewVisible(false)}
      >
 <div className="game-card-v2">
    <div className="header">
      <div  className="header-content" >
        <div className="level-count">
          { [0,1,2,3,4].map( item =>  <div key={item} className={classNames(['level-item',  'level-item-active'])} /> )  }
         
        </div>
        <div className="count-down">
          <img className="clock" src='https://app-resources-luojigou.luojigou.vip/FtYk1U3hzbNiea1x6OS8_ZnCluq-' />
          <div className={classNames(['showCountDownAni', 'flack-className'])} >
            60
          </div>
        </div>
      </div>
    </div>

    <div
      className="content"
      style={{
        background: `url(https://app-resources-luojigou.luojigou.vip/Fqj0sowjX078sk3PgbBlSvT_Ti9R) no-repeat top left`,
        backgroundSize: '100%',
      }}
    >
      <div
        className="board"
        style={{
          background: `url(${bg}) no-repeat center`,
          backgroundSize: '100%',
        }}
      >
        <div className="board-header" id="game-label">
          <div className="trumpt">
            <image className="dog" src='https://app-resources-luojigou.luojigou.vip/Fg6qeptPdjRsg3eDUyuGiXOTSPJV' />
            <image className="trumpt-icon"  src="https://app-resources-luojigou.luojigou.vip/FnahepHJN1cSRD03VEFLebxL5Br-"/>
          </div>
          <div className="tip van-multi-ellipsis--l2">
            我是问题
          </div>
        </div>
        <div className="question">
          <div className="question-card">
            {
              content.map( item => (
              <div
                className="game-item"
                style={{
                  width: item.pw + 'px',
                  height: item.ph + 'px',
                  top: item.py + 'px',
                  left: item.px + 'px',
                }}
                key={item.id}
              >
                <div
                  className="round"
                  style={{
                    backgroundColor: item.color,
                    width: item.iw + 'px',
                    height: item.ih + 'px',
                    top: item.iy + 'px',
                    left: item.ix + 'px',
                  }}
                >
                </div>
                <img
                  style={{
                    width: item.w + 'px',
                    height: item.h + 'px',
                    top: item.y + 'px',
                    left: item.x + 'px',
                    display: 'block'
                  }}
                  src={item.imgUrl}
                />
                {
                  item.bg == 'true' &&
                <div
                  className={classNames(['game-item', "game-bg"])}
                  style={{
                    width: item.pw + 'rpx',
                    height: item.ph + 'rpx',
                    top: item.py + 'rpx',
                    left: item.px + 'rpx',
                  }}
                >
                  <Image
                    style={{
                      width: item.w + 'rpx',
                      height: item.h + 'rpx',
                      top: item.y + 'rpx',
                      left: item.x + 'rpx',
                      display: 'block'
                    }}
                    src={item.imgUrl}
                  />
                </div>
                }
              </div>
              ))
            }
          </div>
          <div className="question-answer" id="right-box">
            {
              answerList.filter( answer => !!answer.imgUrl).map( (item, index) => (
                <div
                  key={item.color}
                  className="answer-item"
                >
                  {   console.log(index)}
                  
                    {/* <div
                      className="answer-round"
                      style={{ backgroundColor: item.color }}
                    >
                    </div> */}
                    <img style={{objectFit: 'cover'}} src={item.imgUrl} />
                  {/* <div className="line" v-if="index !== gameOption.length - 1" /> */}
                </div>
              ))
            }
            
          </div>
        </div>

      </div>
    </div>
    </div>
      </Modal>
    </BaseTmp>
  )

}

export default QuestionBankManage


